# Table of Contents

- [erp-transformation-prepare](<./erp-transformation-prepare.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Phase 2. Prepare the Transformation](<./Phase-2.-Prepare-the-Transformation.md>)
  - [Overview](<./Phase-2.-Prepare-the-Transformation/Overview.md>)
  - [Step 1. Enrich Data](<./Phase-2.-Prepare-the-Transformation/Step-1.-Enrich-Data.md>)
  - [Add Initiatives](<./Phase-2.-Prepare-the-Transformation/Add-Initiatives.md>)
  - [Add Milestones](<./Phase-2.-Prepare-the-Transformation/Add-Milestones.md>)
  - [Structure Your Transformation Program](<./Phase-2.-Prepare-the-Transformation/Structure-Your-Transformation-Program.md>)
  - [Step 2. Evaluate Data](<./Phase-2.-Prepare-the-Transformation/Step-2.-Evaluate-Data.md>)
  - [Step 3. Report and Communicate](<./Phase-2.-Prepare-the-Transformation/Step-3.-Report-and-Communicate.md>)
  - [Was this page helpful?](<./Phase-2.-Prepare-the-Transformation/Was-this-page-helpful.md>)
